@@ -1,29 +1,36 @@
-#ifndef _GSTMM_H_
-#define _GSTMM_H_
+#ifndef _GSTREAMERMM_H_
+#define _GSTREAMERMM_H_
 
 #include <gstreamermm/bin.h>
+#include <gstreamermm/buffer.h>
 #include <gstreamermm/bus.h>
 #include <gstreamermm/caps.h>
+#include <gstreamermm/childproxy.h>
 #include <gstreamermm/clock.h>
 #include <gstreamermm/element.h>
+#include <gstreamermm/elementfactory.h>
 #include <gstreamermm/enums.h>
 #include <gstreamermm/error.h>
 #include <gstreamermm/event.h>
 #include <gstreamermm/format.h>
+#include <gstreamermm/index.h>
 #include <gstreamermm/iterator.h>
 #include <gstreamermm/message.h>
 #include <gstreamermm/object.h>
 #include <gstreamermm/pad.h>
 #include <gstreamermm/padtemplate.h>
 #include <gstreamermm/pipeline.h>
+#include <gstreamermm/plugin.h>
+#include <gstreamermm/pluginfeature.h>
 #include <gstreamermm/query.h>
 #include <gstreamermm/structure.h>
 #include <gstreamermm/systemclock.h>
+#include <gstreamermm/value.h>
 #include <gstreamermm/xml.h>
 
 #include <gstreamermm/init.h>
 #include <gstreamermm/version.h>
 #include <gstreamermm/wrap_init.h>
 
-#endif // _GSTMM_H
+#endif // _GSTREAMERMM_H
 
